==> ejc-bfyjerp-api-3.0.0-20241114.085716-37-sources.jar: com/ejianc/business/project/ProjectRegisterFileVO.java <==
package com.ejianc.business.project;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目基本信息管理-项目资料子实体
 * 
 * @author generator
 * 
 */
public class ProjectRegisterFileVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private String detailFileType; // 文件类型
    private String detailFileForm; // 文件形式：原件，复印件
    private String detailFilePosition; // 文件位置
    private String detailFileId; // 文件id
    private String detailFileName; // 文件名称
    private String docType; // 资料类型：0-项目资料，1-其他盖章资料
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDetailFileType() {
        return detailFileType;
    }

    public void setDetailFileType(String detailFileType) {
        this.detailFileType = detailFileType;
    }
    public String getDetailFileForm() {
        return detailFileForm;
    }

    public void setDetailFileForm(String detailFileForm) {
        this.detailFileForm = detailFileForm;
    }
    public String getDetailFilePosition() {
        return detailFilePosition;
    }

    public void setDetailFilePosition(String detailFilePosition) {
        this.detailFilePosition = detailFilePosition;
    }
    public String getDetailFileId() {
        return detailFileId;
    }

    public void setDetailFileId(String detailFileId) {
        this.detailFileId = detailFileId;
    }
    public String getDetailFileName() {
        return detailFileName;
    }

    public void setDetailFileName(String detailFileName) {
        this.detailFileName = detailFileName;
    }
    public String getDocType() {
        return docType;
    }

    public void setDocType(String docType) {
        this.docType = docType;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250228.085331-160-sources.jar: com/ejianc/business/project/ProjectRegisterFileVO.java <==
package com.ejianc.business.project;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目基本信息管理-项目资料子实体
 * 
 * @author generator
 * 
 */
public class ProjectRegisterFileVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表主键
    private String detailFileType; // 文件类型
    private String detailFileForm; // 文件形式：原件，复印件
    private String detailFilePosition; // 文件位置
    private String detailFileId; // 文件id
    private String detailFileName; // 文件名称
    private String docType; // 资料类型：0-项目资料，1-其他盖章资料
    private Integer copies; // 份数

    public Integer getCopies() {
        return copies;
    }

    public void setCopies(Integer copies) {
        this.copies = copies;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDetailFileType() {
        return detailFileType;
    }

    public void setDetailFileType(String detailFileType) {
        this.detailFileType = detailFileType;
    }
    public String getDetailFileForm() {
        return detailFileForm;
    }

    public void setDetailFileForm(String detailFileForm) {
        this.detailFileForm = detailFileForm;
    }
    public String getDetailFilePosition() {
        return detailFilePosition;
    }

    public void setDetailFilePosition(String detailFilePosition) {
        this.detailFilePosition = detailFilePosition;
    }
    public String getDetailFileId() {
        return detailFileId;
    }

    public void setDetailFileId(String detailFileId) {
        this.detailFileId = detailFileId;
    }
    public String getDetailFileName() {
        return detailFileName;
    }

    public void setDetailFileName(String detailFileName) {
        this.detailFileName = detailFileName;
    }
    public String getDocType() {
        return docType;
    }

    public void setDocType(String docType) {
        this.docType = docType;
    }
    
}
